# JupySQL

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Run SQL in Jupyter/IPython via a `%sql` and `%%sql` magics.

## Features

- [Pandas integration](https://jupysql.readthedocs.io/en/latest/pandas.html)
- [SQL composition (no more hard-to-debug CTEs!)](https://jupysql.readthedocs.io/en/latest/compose.html)
- [Plot massive datasets without blowing up memory](https://jupysql.readthedocs.io/en/latest/plot-large.html)
- [DuckDB integration](https://jupysql.readthedocs.io/en/latest/duckdb.html)

## Installation

```
pip install jupysql
```

## Documentation

[Click here to see the documentation.](https://jupysql.readthedocs.io)


## Credits

This project is a fork of [ipython-sql](https://github.com/catherinedevlin/ipython-sql); the objective is to turn this project into a full-featured SQL client for Jupyter. We're looking for feedback and taking feature requests, so please [join our community](https://ploomber.io/community) and enter the #jupysql channel.
